@@ -28,14 +28,18 @@ use warnings;
 use strict;
 
 # constants, change this if needed (also in the client script?)
-use constant SERVERHOST => 'localhost';
-use constant SERVERPORT => '8877';
-
-use constant ERROR_NS   => 'http://namesservice.thomas_bayer.com/error';
+my $serverhost = 'localhost';
+my $serverport = '8877';
 
 # To make Perl find the modules without the package being installed.
-use lib '../../lib'                 # This server implementation
-      , '.';                        # To access My*.pm helpers
+use lib '../../lib'   # The server implementation, not installed
+      , '.';          # To access My*.pm helpers
+
+my $wsdl_filename = 'namesservice.wsdl';
+my @more_schemas  = 'namesservice.xsd';
+
+# useful to make constants (or vars) for namespaces
+use constant ERROR_NS  => 'http://namesservice.thomas_bayer.com/error';
 
 # This could come from a database...
 use MyExampleData  qw/$namedb/;
@@ -43,8 +47,8 @@ use MyExampleData  qw/$namedb/;
 # This module defines my additional (non-WSDL) calls
 use MyExampleCalls;
 
-# All the other XML modules should be automatically included.
-use XML::Compile::SOAP::HTTPDaemon;
+# Some other XML modules are automatically included.
+use XML::Compile::SOAP::Daemon::NetServer;
 use XML::Compile::WSDL11;
 use XML::Compile::SOAP11;
 use XML::Compile::Util    qw/pack_type/;
@@ -100,7 +104,7 @@ error __x"No filenames expected on the command-line"
 # Create the daemon set-up
 #
 
-my $daemon = XML::Compile::SOAP::HTTPDaemon->new
+my $daemon = XML::Compile::SOAP::Daemon::NetServer->new
   ( 
     # You may wish to use other daemon implementations, for instance
     # when your platform does not have a fork.  You may also provide
@@ -114,8 +118,11 @@ my $daemon = XML::Compile::SOAP::HTTPDaemon->new
 
 # Of course, you find this information in the applicable manual pages of
 # the XML-Compile-SOAP distributions.
-my $wsdl = XML::Compile::WSDL11->new('namesservice.wsdl');
-$wsdl->importDefinitions('namesservice.xsd');
+my $wsdl = XML::Compile::WSDL11->new($wsdl_filename);
+
+# Some WSDLs import or include external schemas. In XML::Compile, you
+# have to pass them explicitly. Single SCALAR or ARRAY.
+$wsdl->importDefinitions(\@more_schemas);
 
 # The error namespace I use in this example is not defined in the
 # wsdl neither the xsd, so have to add it explicitly.
@@ -143,6 +150,8 @@ $daemon->operationsFromWSDL
   , callbacks => \%callbacks
   );
 
+$daemon->setWsdlResponse($wsdl_filename);
+
 # Add a handler which is not defined in a WSDL
 create_get_name_count $daemon;
 
@@ -154,14 +163,16 @@ create_get_name_count $daemon;
 # replace the 'default' output 'PERL' with output to syslog
 dispatcher SYSLOG => 'default', mode => $mode;
 
+print "Staring daemon on $serverhost:$serverport\n";
+
 $daemon->run
   ( 
     # any Net::Server option. Difference SOAP daemon extensions add extra
     # configuration options. It also depends on the Net::Server
     # implementation you base the SOAP daemon on.  See new(base_on)
     name    => 'NamesService'
-  , host    => SERVERHOST
-  , port    => SERVERPORT
+  , host    => $serverhost
+  , port    => $serverport
 
     # Net::Server::PreFork parameters
   , min_servers => 1
